package com.ruoyi.web.work.controller;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.web.work.domain.Statement;
import com.ruoyi.web.work.domain.StatementDetail;
import com.ruoyi.web.work.service.IStatementDetailService;
import com.ruoyi.web.work.service.IStatementService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 结算单管理
 *
 * @author lsw
 * @date 2024-04-20
 */
@RestController
@RequestMapping("/work/statement")
public class StatementController extends BaseController {
    @Autowired
    private IStatementService statementService;

    @Autowired
    private IStatementDetailService detailService;

    /**
     * 制单管理
     */
    @PreAuthorize("@ss.hasPermi('work:statement:make')")
    @GetMapping("/make")
    public TableDataInfo make(Statement statement) {
        statement.setAuditors(false);
        statement.setCompanyId(getLoginUser().getUser().getCompanyId());
        startPage();
        List<Statement> list = statementService.selectList(statement);
        return getDataTable(list);
    }

    /**
     * 结算单管理
     */
    @PreAuthorize("@ss.hasPermi('work:statement:manage')")
    @GetMapping("/manage")
    public TableDataInfo manage(Statement statement) {
        statement.setState(1);
        statement.setAudit(null);
        statement.setGive(null);
        statement.setAuditors(false);
        statement.setCompanyId(getLoginUser().getUser().getCompanyId());
        startPage();
        List<Statement> list = statementService.selectList(statement);
        return getDataTable(list);
    }

    /**
     * 结算单审核
     */
    @PreAuthorize("@ss.hasPermi('work:statement:audit')")
    @GetMapping("/audit")
    public TableDataInfo audit(Statement statement) {
        statement.setState(1);
        statement.setAuditors(true);
        statement.setCompanyId(getLoginUser().getUser().getCompanyId());
        startPage();
        List<Statement> list = statementService.selectList(statement);
        return getDataTable(list);
    }

    /**
     * 发放业务费
     */
    @PreAuthorize("@ss.hasPermi('work:statement:give')")
    @GetMapping("/give")
    public TableDataInfo give(Statement statement) {
        statement.setState(1);
        statement.setAudit(2);
        statement.setAuditors(false);
        statement.setCompanyId(getLoginUser().getUser().getCompanyId());
        startPage();
        List<Statement> list = statementService.selectList(statement);
        return getDataTable(list);
    }

    @PreAuthorize("@ss.hasPermi('work:statement:audit')")
    @Log(title = "结算单审核通过", businessType = BusinessType.UPDATE)
    @GetMapping("/audit/success/{id}")
    public AjaxResult auditSuccess(@PathVariable("id") Long id) {
        return statementService.auditSuccess(id);
    }

    @PreAuthorize("@ss.hasPermi('work:statement:manage')")
    @Log(title = "提交结算单审核", businessType = BusinessType.UPDATE)
    @GetMapping("/manage/submit/{id}")
    public AjaxResult manageSubmit(@PathVariable("id") Long id) {
        return statementService.manageSubmit(id);
    }

    @PreAuthorize("@ss.hasPermi('work:statement:manage')")
    @Log(title = "撤回结算单审核", businessType = BusinessType.UPDATE)
    @GetMapping("/manage/cancel/{id}")
    public AjaxResult manageCancel(@PathVariable("id") Long id) {
        return statementService.manageCancel(id);
    }

    @GetMapping("/detailList")
    public TableDataInfo detailList(StatementDetail detail) {
        startPage();
        List<StatementDetail> list = detailService.selectList(detail);
        return getDataTable(list);
    }

    @PreAuthorize("@ss.hasPermi('work:statement:make')")
    @Log(title = "生成结算单", businessType = BusinessType.UPDATE)
    @GetMapping("/make/generate/{id}")
    public AjaxResult makeGenerate(@PathVariable("id") Long id) {
        return statementService.makeGenerate(id);
    }


    @PreAuthorize("@ss.hasAnyPermi('system:user:add,work:statement:give')")
    @GetMapping(value = "/detail/{id}")
    public AjaxResult detail(@PathVariable("id") Long id) {
        return AjaxResult.success(statementService.getById(id));
    }


    @PreAuthorize("@ss.hasPermi('work:statement:make')")
    @Log(title = "创建结算单", businessType = BusinessType.INSERT)
    @PostMapping("/make/add")
    public AjaxResult makeAdd(@Validated Statement statement) throws Exception {
        ExcelUtil<StatementDetail> util = new ExcelUtil<StatementDetail>(StatementDetail.class);
        List<StatementDetail> detailList = util.importExcel(statement.getFile().getInputStream());
        return statementService.makeAdd(detailList, statement);
    }

    @PreAuthorize("@ss.hasPermi('work:statement:make')")
    @Log(title = "删除结算单", businessType = BusinessType.DELETE)
    @GetMapping("/make/remove/{id}")
    public AjaxResult makeRemove(@PathVariable Long id) {
        return statementService.makeRemove(id);
    }

    @PreAuthorize("@ss.hasPermi('work:statement:make')")
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response) {
        ExcelUtil<StatementDetail> util = new ExcelUtil<StatementDetail>(StatementDetail.class);
        util.importTemplateExcel(response, "结算单");
    }
}
